// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package xflags

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

type Definition struct {
	Verbose bool `short:"v" long:"verbose" description:"Show verbose debug information"`
	Serve   struct {
		Host string `short:"h" long:"host" description:"Host to bind to" default:"localhost"`
		Port int    `short:"p" long:"port" description:"Port to bind to" default:"8080"`
	} `command:"serve" description:"Run the HTTP server" call:"DoServe"`
}

func (d *Definition) DoServe(_ *Settings[Definition]) {
	// do something
}

func TestReadMeInit(t *testing.T) {
	setting := New("test", Definition{})
	setting.Parse([]string{"-v", "serve", "-h", "localhost", "-p", "8080"})
	setting.Execute()
	assert.True(t, setting.definitions.Verbose)
	assert.False(t, setting.HasErrors())
}

func TestReadMeInit2(t *testing.T) {
	cmd := New("test", Definition{})
	cmd.Parse([]string{"serve"})
	assert.False(t, cmd.definitions.Verbose)
	assert.False(t, cmd.HasErrors())
}
